# A list of things left to do for this project

* Cache symbols on disk, to avoid redundant network calls



# Considerations

* Consider implementing @dataclass and @dataclass_json from scratch to avoid third-party dependency
